# commitlint-config-inplus

本包提供了《印嘉前端规范 - Git 规范》配套的 [commitlint 可共享配置](https://commitlint.js.org/#/concepts-shareable-config)，用于对 git commit message 进行校验。

## 安装

除了本包，你需要同时安装 [@commitlint/cli](https://www.npmjs.com/package/@commitlint/cli)：

```bash
npm install commitlint-config-inplus @commitlint/cli --save-dev
```

## 使用

在你的 `commitlint.config.js` 中继承本包:

```javascript
module.exports = {
  extends: ['inplus'],
}
```

### 配合 commitizen 和 husky 使用（推荐）

#### 安装

```bash
npm install commitizen husky --save-dev
```

#### 配置 commitizen

```bash
# npm 5.2+
npx commitizen init cz-conventional-changelog --save-dev --save-exact
```

这时候，你的 `package.json` 会出现下面配置：

```json
...
  "config": {
    "commitizen": {
      "path": "cz-conventional-changelog"
    }
  }
```

#### 设置 husky hooks

1. 添加 `prepare-commit-msg` hook

```sh
npx husky add .husky/prepare-commit-msg "exec < /dev/tty && npx cz --hook || true"
```

2. 添加 `commit-msg` hook

```sh
npx husky add .husky/commit-msg 'npx --no -- commitlint --edit "$1"'
```

## 更多信息可参考:

- [commitlint 文档](https://commitlint.js.org/#/)
- [commitizen 文档](https://github.com/commitizen/cz-cli)
- [husky 文档](https://typicode.github.io/husky/#/)
